@@ -137,7 +137,7 @@ meteo_imgw_monthly <- function(rank = "synop", year, status = FALSE, coords = FA
   #station selection
   if (!is.null(station)) {
     if (is.character(station)) {
-      all_data <- all_data[all_data$`Nazwa stacji` %in% station, ]
+      all_data <- all_data[substr(all_data$`Nazwa stacji`,1,nchar(station))==station, ]
       if (nrow(all_data) == 0){
         stop("Selected station(s) is not available in the database.", call. = FALSE)
       }
